@@ -9,17 +9,17 @@ from aesara.graph.op import compute_test_value
 from aesara.graph.opt import GlobalOptimizer, LocalOptimizer
 from aesara.graph.optdb import OptimizationQuery
 from aesara.tensor.basic_opt import ShapeFeature
-from aesara.tensor.random.op import RandomVariable
 from aesara.tensor.var import TensorVariable
 
+from aeppl.abstract import MeasurableVariable, get_measurable_outputs
 from aeppl.logprob import _logprob
-from aeppl.opt import PreserveRVMappings, logprob_canonicalize
+from aeppl.opt import PreserveRVMappings, logprob_rewrites_db
 from aeppl.utils import rvs_to_value_vars
 
 
 def joint_logprob(
     var: TensorVariable,
-    rv_values: Optional[Dict[TensorVariable, TensorVariable]] = None,
+    rv_values: Dict[TensorVariable, TensorVariable],
     warn_missing_rvs: bool = True,
     extra_rewrites: Optional[Union[GlobalOptimizer, LocalOptimizer]] = None,
     **kwargs,
@@ -93,6 +93,7 @@ def joint_logprob(
         clone=True,
         memo=memo,
         copy_orphans=False,
+        copy_inputs=False,
         features=[ShapeFeature()],
     )
 
@@ -106,7 +107,7 @@ def joint_logprob(
 
     fgraph.attach_feature(rv_remapper)
 
-    logprob_canonicalize.query(OptimizationQuery(include=["basic"])).optimize(fgraph)
+    logprob_rewrites_db.query(OptimizationQuery(include=["basic"])).optimize(fgraph)
 
     if extra_rewrites is not None:
         extra_rewrites.optimize(fgraph)
@@ -126,42 +127,57 @@ def joint_logprob(
         node = q.popleft()
 
         if not any(o in lifted_rv_values for o in node.outputs):
-            if isinstance(node.op, RandomVariable) and warn_missing_rvs:
+            if (
+                isinstance(node.op, MeasurableVariable)
+                and not getattr(node.default_output().tag, "ignore_logprob", False)
+                and warn_missing_rvs
+            ):
                 warnings.warn(
                     "Found a random variable that was neither among the observations "
                     f"nor the conditioned variables: {node}"
                 )
             continue
 
-        if isinstance(node.op, RandomVariable):
-            q_rv_var = node.outputs[1]
-            q_rv_value_var = replacements[q_rv_var]
+        if isinstance(node.op, MeasurableVariable):
 
-            # Replace `RandomVariable`s in the inputs with value variables.
-            # Also, store the results in the `replacements` map so that we
-            # don't need to redo these replacements.
-            value_var_inputs, _ = rvs_to_value_vars(
-                node.inputs,
-                initial_replacements=replacements,
-            )
+            outputs = get_measurable_outputs(node.op, node)
 
-            q_logprob_var = _logprob(
-                node.op, q_rv_value_var, *value_var_inputs, name=q_rv_var.name, **kwargs
-            )
+            for q_rv_var in outputs:
 
-            if q_rv_var.name:
-                q_logprob_var.name = f"{q_rv_var.name}_logprob"
+                if getattr(q_rv_var.tag, "ignore_logprob", False):
+                    continue
+
+                q_rv_value_var = replacements[q_rv_var]
+
+                # Replace `RandomVariable`s in the inputs with value variables.
+                # Also, store the results in the `replacements` map so that we
+                # don't need to redo these replacements.
+                (q_rv_value_var, *value_var_inputs), _ = rvs_to_value_vars(
+                    [q_rv_value_var, *node.inputs],
+                    initial_replacements=replacements,
+                )
+
+                q_logprob_var = _logprob(
+                    node.op,
+                    q_rv_value_var,
+                    *value_var_inputs,
+                    name=q_rv_var.name,
+                    **kwargs,
+                )
+
+                if q_rv_var.name:
+                    q_logprob_var.name = f"{q_rv_var.name}_logprob"
+
+                if logprob_var is None:
+                    logprob_var = q_logprob_var
+                else:
+                    logprob_var += q_logprob_var
 
         else:
             raise NotImplementedError(
                 f"A measure/probability could not be derived for {node}"
             )
 
-        if logprob_var is None:
-            logprob_var = q_logprob_var
-        else:
-            logprob_var += q_logprob_var
-
     # Recompute test values for the changes introduced by the replacements
     # above.
     if config.compute_test_value != "off":
